package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.34.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.34.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````(`*``!````0!D!`#0```!HD0````0`!30`(``)
M`"@`'``;``$``'!`A@``0(8!`$"&`0`(````"`````0````$````!@```#0`
M```T``$`-``!`"`!```@`0``!`````0````#````5`$``%0!`0!4`0$`&0``
M`!D````$`````0````$````````````!`````0!,A@``3(8```4```````$`
M`0```$R&``!,A@(`3(8"`,0)``#L&0``!@```````0`"````7(8``%R&`@!<
MA@(`$`$``!`!```&````!`````0```!P`0``<`$!`'`!`0!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71D3(8`
M`$R&`@!,A@(`M`D``+0)```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`A9':[(+$=C#%BPCF)QT,BL?S9CP$
M````$`````$```!'3E4```````,````"`````````&$````$````(`````H`
M``"H$A```$01```"0`!6`'`8@@``,`@`$!$``!`"`B@`````````2`(@"@`*
M``2$`JA`"`5@80"$"#Y"/)<``0`()%B`!(E@#)-X"4)*0$0`0``!`4,)`$"`
MC,"$``"0D!"#"0`(`1"`@$!`P@F`#$"(`D$`(,`@!`D`D``D#I-"0`0`````
M````!0````8````(``````````````````````````D````+````#`````X`
M```/````$````!$````4`````````````````````````!8````9````&@``
M`!T````>````'P```"`````A````(@```"0````H`````````"H`````````
M`````"L````L````+0```"X`````````,@```#,````U````-@``````````
M````-P```#H````[`````````#P````]````/P```$$```!$`````````$4`
M`````````````$8`````````1P``````````````````````````````````
M`$@```!)`````````$L`````````30```%````!2````````````````````
M`````%,```!7````6````%D`````````6@``````````````7```````````
M````7@```&````!A````8P```&8```!?EI,<HUKOD%;;DQS#CH?_#3J7"])1
M!(2!=((->_!*:W94/)3-/PRO]R/.((D'<-/59-1\9J_,9BY./?;;]P!>!J2'
M_P&O-.C.2J[_SMY'+>&G`@KC1\8!Q@[@/3Y^EGSM/Y`":QJ>4,6)!9!AF.\2
M`2/YI.N$BAQ"^M>'G;N3'$)%U>Q0[A'CAOF<@7WM$0^ZE9,<6YH[#T%-G7RG
MW:-K6>^7>3GRBQP,%.*>!#*EA:("]AG;S>.>^Z%L8,@Y0!\S8MOM/YY"1.G[
MP\)*(GW_"HH05^W>DQRM2^/`V7%8'"O0X2(:G]:]+0ZQ<U@[0!_#Y3\LF"+4
M:+KCDGPA_^0.;WII^I.M!&+?A2!/5Z2;EL6YG$!0&WU?,;B"#;[:5QNS`8MO
MO-!+?79OXW"90NZA:@E#UI\BQZ@A8F0'?JF<FV+0^H+L+/:+:W^:?(?PEGP5
MC"7,[PM1^9!U@@U#9DL0/*TY#1?J6O&FFY,<H^#[25>26E+VOOR1_=+O#V[%
MWQ]\D!#I+=_^2"[%F[;)U;)Q``````````````````````$`````````````
M`"`````=```````````````@````+```````````````(````,4"````````
M`````!(```"R`0`````````````2````0`(`````````````$@```!T"````
M`````````!(```#F`P```)`"```````@`!<`;`$`````````````$@```!8"
M`````````````!(```!<`0``C!0!```````2````:P,``!"0`@``````$``8
M`-D!`````````````!(```#[`0`````````````2````)@0```R0`@`$````
M$0`7`)X$``!(,@$`4`(``!(`#0#``P``A",!```!```2``T`S`(`````````
M````$@```.$!`````````````!(```"'`@`````````````2````J`,``#B@
M`@``````$``8`(L#`````````````!(```#,`P``^"H!`%`'```2``T```0`
M`'@@`0#0````$@`-`+,#``!<(P$`*````!(`#0`(`@`````````````2````
MU`$`````````````$@```$,!`````````````!(```!*!```;$,!`$0!```2
M``T`WP(``!"0`@`$````(0`8`*L!`````````````!(```"5`0``````````
M```2````8P(`````````````$@```-D#```P0@$`/`$``!(`#0`R`@``````
M```````2````H`,``!"0`@``````$``7`$T"`````````````!(```!C````
MM!8!```````2````$`(`````````````$@```)<"`````````````!(```#.
M`0`````````````2````I@$`````````````$@```.`"```0D`(`!````"$`
M&``U!```.*`"```````0`!@`@`(``""0`@`$````$0`8`$H#```010$`!```
M`!(`#0!.`0`````````````2````*@$`````````````$@```!8$``"P1`$`
M8````!(`#0!U!```["D!``P!```2``T`Z@$`````````````$@```.H#``!`
M&0$``````!(`#0"#```````````````2````CP``````````````$@```&H"
M`````````````!(```"S````&)`"``$````1`!@`*P(`````````````$@``
M`/$#```P10$`!````!$`#P!4!```$)`"```````0`!@`G@(`````````````
M$@```+8"`````````````!(```!&```````````````2````P```````````
M````$@```&`$``!$(`$`-````!(`#0#S```````````````2````,`0``#B@
M`@``````$``8`&@$``!,(0$`$`(``!(`#0#H`@`````````````2````N@$`
M````````````$@```*0``````````````!(```#1````%)`"``0````1`!@`
MW@(``!"0`@`$````$0`8`!P!`````````````!(````Y`@`````````````2
M````IP,``#B@`@``````$``8`(<$``!,*0$`B````!(`#0!T````````````
M```2````>`(`````````````$@```-P``````````````!(```#D`P```)`"
M```````0`!<`J`(`````````````$@```/H"``!8A@(`!````!$`%`!Y`P``
MU"D!`!@````2``T`B@$`````````````$@```'<!`````````````!(```#9
M`@``(!<!`"`"```2``T`^```````````````$@```)4$``"T00$`?````!(`
M#0".`@`````````````2````6P(`````````````$@```$<"````````````
M`!(```"#`0`````````````2````O@(`````````````$@```"0"````````
M`````!(````]!```A"0!`,@$```2``T`_0``````````````$@```&("````
M`````````!(````"`@`````````````2````E`,``)@T`0`T`0``$@`-`%0`
M`````````````!(````Z`0`````````````2````6@,``$@A`0`$````$@`-
M``D!```\%@$``````!(`````7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE
M`%]?9VUO;E]S=&%R=%]?`%])5$U?<F5G:7-T97)434-L;VYE5&%B;&4`4&5R
M;%]S>7-?=&5R;0!097)L7W-Y<U]I;FET,P!097)L7V%T9F]R:U]L;V-K`'!E
M<FQ?8V]N<W1R=6-T`%!E<FQ?9V5T7W-V`%!E<FQ?8W)O86M?;F]C;VYT97AT
M`%!E<FQ?<W9?<V5T<'9N`%!,7V1O7W5N9'5M<`!097)L7VYE=UA37V9L86=S
M`%!,7W1H<E]K97D`4&5R;%]C<F]A:U]M96UO<GE?=W)A<`!P97)L7V9R964`
M4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`
M4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`<&5R;%]D97-T
M<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M
M86QL;V,`<&5R;%]A;&QO8P!?7V5R<FYO7VQO8V%T:6]N`')E860`;W!E;C8T
M`&QS965K-C0`<'1H<F5A9%]G971S<&5C:69I8P!C;&]S90!E>&ET`'-T<FYC
M;7``8VQO<V5D:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A
M;&QO8P!A8F]R=`!M96UC:'(`9V5T<&ED`'-T<F1U<`!S=')T;VL`<W1R;&5N
M`&UE;7-E=`!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!M96UC<'D`;'-T
M870V-`!?7W-T<FYC<'E?8VAK`&]P96YD:7(`<W1D97)R`&=E='5I9`!R96%D
M;&EN:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R:6YT9E]C:&L`;65M;6]V90!A
M8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!?7W)E
M9VES=&5R7V%T9F]R:P!?7W-T86-K7V-H:U]G=6%R9`!L:6)P97)L+G-O+C4N
M,S0`;&EB<'1H<F5A9"YS;RXP`&QI8F,N<V\N-@!L9"UL:6YU>"UA<FUH9BYS
M;RXS`%]?;&EB8U]C<W5?9FEN:0!P87)?8W5R<F5N=%]E>&5C`%]?8G-S7W-T
M87)T7U\`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N=7``
M7V5D871A`%]?8G-S7V5N9%]?`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P
M87)?;6MT;7!D:7(`<VAA7W5P9&%T90!?7V1A=&%?<W1A<G0`7TE/7W-T9&EN
M7W5S960`<&%R7V-U<G)E;G1?97AE8U]P<F]C`%]?;&EB8U]C<W5?:6YI=`!M
M>5]P87)?<&P`7V5N9`!?7V5N9%]?`'!A<E]I;FET7V5N=@!S:&%?9FEN86P`
M7U]B<W-?<W1A<G0`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P7VQI
M8G!A=&@`<&%R7V5N=E]C;&5A;@!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%2
M7T)/3U0`1TQ)0D-?,BXT`$=,24)#7S(N,S,``````0`!``$``@`#``(``@`!
M``$``@`!``$``@`"``$``0`!``(``@`"``$``@`!``$``0`"``(``0`!``(`
M`P`#``4``0`"``$``@`!``(``@`#``,``@`!``(``0`!``$``0`!``(``0`!
M``$``@`!``(``0`!``(``@`!``$``0`!``$``0`"``,``0`!``(``0`"``$`
M`0`!``(``0`!``(`!``!``$``0`!``(``0`"``(``@`"``(``@`!``$`!0`"
M``$``0`!``$``0````$``0`V`P``$````"`````4:6D-```$`+0$````````
M`0`!`!P#```0````(````!1I:0T```,`M`0````````!``(`+`,``!``````
M````LY&6!@``!0"^!```$````!1I:0T```(`M`0```````!TB`(`%0(``%B&
M`@`44@``$)`"`!1(```4D`(`%$<``!B0`@`4.```()`"`!0M``!XAP(`%@8`
M`'R'`@`6!```@(<"`!86``"$AP(`%BH``(B'`@`6%```C(<"`!8]``"0AP(`
M%E<``)2'`@`66@``F(<"`!8+``"<AP(`%F$``*"'`@`66P``I(<"`!9-``"H
MAP(`%D$``*R'`@`6-P``L(<"`!9>``"TAP(`%C,``+B'`@`61```O(<"`!8A
M``#`AP(`%@X``,2'`@`6&@``R(<"`!8O``#,AP(`%DD``-"'`@`660``U(<"
M`!94``#8AP(`%@4``-R'`@`650``X(<"`!9.``#DAP(`%A\``.B'`@`67```
M[(<"`!82``#PAP(`%C```/2'`@`6`@``^(<"`!8'``#\AP(`%AL```"(`@`6
M(P``!(@"`!9D```(B`(`%B@```R(`@`6-0``$(@"`!8@```4B`(`%E$``!B(
M`@`6-@``'(@"`!8<```@B`(`%F(``"2(`@`62@``*(@"`!9G```LB`(`%CX`
M`#"(`@`68```-(@"`!8)```XB`(`%B4``#R(`@`6/P``0(@"`!8*``!$B`(`
M%ET``$B(`@`63P``3(@"`!8Y``!0B`(`%B8``%2(`@`6/```6(@"`!9&``!<
MB`(`%F4``&"(`@`6#0``9(@"`!8G``!HB`(`%BD``&R(`@`6$P``<(@"`!9%
M```(0"WI60$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[E1',!``#&C^(7RHSB1/.\
MY0#&C^(7RHSB//.\Y0#&C^(7RHSB-/.\Y0#&C^(7RHSB+/.\Y0#&C^(7RHSB
M)/.\Y0#&C^(7RHSB'/.\Y0#&C^(7RHSB%/.\Y0#&C^(7RHSB#/.\Y0#&C^(7
MRHSB!/.\Y0#&C^(7RHSB_/*\Y0#&C^(7RHSB]/*\Y0#&C^(7RHSB[/*\Y0#&
MC^(7RHSBY/*\Y0#&C^(7RHSBW/*\Y0#&C^(7RHSBU/*\Y0#&C^(7RHSBS/*\
MY0#&C^(7RHSBQ/*\Y0#&C^(7RHSBO/*\Y0#&C^(7RHSBM/*\Y0#&C^(7RHSB
MK/*\Y0#&C^(7RHSBI/*\Y0#&C^(7RHSBG/*\Y0#&C^(7RHSBE/*\Y0#&C^(7
MRHSBC/*\Y0#&C^(7RHSBA/*\Y0#&C^(7RHSB?/*\Y0#&C^(7RHSB=/*\Y0#&
MC^(7RHSB;/*\Y0#&C^(7RHSB9/*\Y0#&C^(7RHSB7/*\Y0#&C^(7RHSB5/*\
MY0#&C^(7RHSB3/*\Y0#&C^(7RHSB1/*\Y0#&C^(7RHSB//*\Y0#&C^(7RHSB
M-/*\Y0#&C^(7RHSB+/*\Y0#&C^(7RHSB)/*\Y0#&C^(7RHSB'/*\Y0#&C^(7
MRHSB%/*\Y0#&C^(7RHSB#/*\Y0#&C^(7RHSB!/*\Y0#&C^(7RHSB_/&\Y0#&
MC^(7RHSB]/&\Y0#&C^(7RHSB[/&\Y0#&C^(7RHSBY/&\Y0#&C^(7RHSBW/&\
MY0#&C^(7RHSBU/&\Y0#&C^(7RHSBS/&\Y0#&C^(7RHSBQ/&\Y0#&C^(7RHSB
MO/&\Y0#&C^(7RHSBM/&\Y0#&C^(7RHSBK/&\Y0#&C^(7RHSBI/&\Y0#&C^(7
MRHSBG/&\Y0#&C^(7RHSBE/&\Y0#&C^(7RHSBC/&\Y0#&C^(7RHSBA/&\Y0#&
MC^(7RHSB?/&\Y0#&C^(7RHSB=/&\Y0#&C^(7RHSB;/&\Y0#&C^(7RHSB9/&\
MY0#&C^(7RHSB7/&\Y0#&C^(7RHSB5/&\Y7!`+>D@T$WBX#&?Y10`C>40$(WE
M#""-Y10`C>(0$(WB#""-X@`PD^4<,(WE`#"@XY[__^NX(9_EN`&?Y0(0H.%K
M"P#KL#&?Y0!0T^4``%7CJ$&?%0D``!IP___KH"&?Y0``4.,,`(+E7@``"HQ!
MG^5&___K``"4Y=W__^M[5\#E``"4Y=K__^L`,*#A``"4Y<8CT^4"((+CQB/#
MY=3__^L48)WE!""&X@<!<N,#8(;BQC/0Y0$P@^/&,\#E10``B@(!H.%;___K
M."&?Y1`0G>4L09_E%%"=Y0$`5>,`,*#A!`"2Y0`@D>4$,(3E`""#Y10AG^4(
M`(/E!""#Y0PAG^4,((/E-```V@0`0>(%`8#@#,"#X@3@L>4``%'A!."LY?O_
M_QH#4(7B`!"@XP`0C>4&(*#A!1&#YPP`E.70$)_E?O__ZP!04.(2```*#`"4
MY2G__^N\`)_E&!"-XFL``.L``%#C#P``"@P`E.4*___K;/__ZW0PG^4`()/E
M'#"=Y0(@,^``,*#C%0``&@4`H.$@T(WB<("]Z`P`E.6%___K`%"@X>C__^H(
M`)3E``!0XP$```KO!@#KZO__ZE@`G^48$(WB40``ZP``4.,(`(3EY/__"O;_
M_^IG___K!%"@X]#__^KU_O_K`0"@XRG__^M8A@(`/!8!`+06`0`8D`(`%)`"
M`"B0`@`(D`(`R$@!`,Q(`0#4'P$`B$8!`"1&`0``L*#C`."@XP00G>0-(*#A
M!"`MY00`+>40P)_E!,`MY0P`G^4,,)_E!O__ZU___^L010$`(!<!`+!$`0`4
M,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$!___JX&T!``@!```8`)_E&#"?Y0``
M4^$>_R\!$#"?Y0``4^,>_R\!$_\OX1"0`@`0D`(``````"0`G^4D,)_E`#!#
MX*,?H.%#$8'@P1"PX1[_+P$0,)_E``!3XQ[_+P$3_R_A$)`"`!"0`@``````
M$$`MZ1A`G^4`,-3E``!3XQ"`O1C@___K`3"@XP`PQ.40@+WH))`"`.;__^KP
M1RWI`)!0XBH```JT,)_E`("3Y0``6.,H```*`%#9Y0%PH.$``%7C/0!5$P%0
MH!,`4*`#$0``&@!`F.4``%3C#```"@A@H.$$`*#A!2"@X0D0H.$6___K``!0
MXP(``!H%,-3G/0!3XPL```H$0+;E``!4X_/__QH$`*#A\(>]Z`E0H.$!,/7E
M``!3XST`4Q/[__\:"5!%X.;__^H(8$;@`5"%XD9AH.$%0(3@!`"@X0!@A^7P
MA[WH"4"@X>W__^H(0*#AZ___ZA"0`@!(,9_E\$$MZ0!04.)XT$WB`#"3Y70P
MC>4`,*#C`@``"@`PU>4``%/C!P``&APQG^4`()/E=#"=Y0(@,^``,*#C00``
M&GC0C>+P@;WHA?[_ZP!`4.+T__\*]'"?Y00`H.'7_O_K``!0XRD```H3,-#E
M$V"`XBX`4^,"```:`3#6Y0``4^/T__\*$S#0Y2X`4^,D```*!0"@X8K^_^L`
M@*#A!@"@X8?^_^L``(C@`@"`XG+^_^L',*#A`"#@XP$0H.,$8(WE`%"-Y0!@
MH.&,_O_K"!"-X@8`H.%'_O_K`0!PXP8`H.$#```*&#"=Y0\Z`^(!"5/C$@``
M"D+^_^L&`*#A'/[_ZP0`H.&M_O_K``!0X]7__QH$`*#AN_[_ZP4`H.$@_O_K
MP/__Z@$PUN4N`%/CU___&@(PUN4``%/CQO__"M/__^JM___KZ___ZB3^_^M8
MA@(`Q$4!`!!`+>EPT$WB<#"?Y0T0H.$`0*#A`#"3Y6PPC>4`,*#C!_[_ZP``
M4.,``*`3!```&A`PG>4/.@/B"@I3XP$)4Q,'```*-#"?Y0`@D^5L,)WE`B`S
MX``PH.,'```:<-"-XA"`O>@"$*#C!`"@X7+^_^L0#V_AH`*@X?'__^H"_O_K
M6(8"`'!`+>D!VDWB"-!-XM@PG^4`8*#A`0J-X@0`@.(`,)/E`#"`Y0`PH./`
M()_EP`"?Y0%0H.$$$(WB!_[_ZP#`4.(5``#:"#"-X@%`3.($X(/@!#!>Y0``
M4^,@```:``!4XPT```H$(*#A+Q"@XP0`C>)-_O_K``!0XP<```IT,)_E``"3
MY6S^_^L$,*#A!""-X@80H.%6_O_K!0``ZE0PG^4``)/E9/[_ZP4@H.$&$*#A
MYOW_ZP$:C>(L,)_E!!"!X@`@D^4`,)'E`B`SX``PH.,$```:`=J-X@C0C>)P
M@+WH#$"@X=[__^K&_?_K6(8"`/\/``#,10$`%)`"`/!'+>D!0*#A`##1Y>`A
MG^4(T$WB/0!3XP%`@0(`4*#A!`"@X0`@DN4$((WE`""@X^[]_^L-$*#A`&"@
MX04`H.$%___K`)!0XCP```KG_?_K``!6X3,``)H`<)WEE(&?Y0=QH.$`,-7E
M``!3XST`4Q,!,*`3`#"@`P4```H%,*#A`2#SY0``4N,]`%(3^___&@4P0^`"
M`(;B`P"`X`!@F.7`_?_K``!0XP<`AN<5```*`""8Y04`H.$!,-#D!Q"2YP``
M4^,]`%,3`##!Y08```H!(('B`3#0Y`(0H.$]`%/C``!3$P$PPN3Y__\:`2"@
MX3TPH.,`,,'E`3#4Y```4^,!,.+E^___&N0PG^4`()/E!#"=Y0(@,^``,*#C
M,P``&@C0C>+PA[WH`9!)X@$PU.0``%/C`3#IY?O__QKQ___JL("?Y0!PF.4`
M,)?E``!3XR,```H',*#A!""SY0D0H.$``%+C`9")XOK__QH#$('B`1&@X8`P
MG^4`()/E``!2XP\``!H!(*#C`0"@X0`@@^6$_?_K`*!0XMK__PH'$*#A"7&@
MX0<@H.$Y_?_K`*"(Y0"0C>4!D(GB`#"@XPDQBN>G___J!P"@X5O]_^L``%#C
M`*"@X0``B.7*__\*"7&@X?+__^H#D*#A"!"@X^#__^I%_?_K6(8"`!"0`@`H
MD`(`$$`MZ0C03>)$0)_E``"4Y<K]_^L``)3ER/W_ZS0PG^4T()_E-!"?Y87]
M_^L``)3EPOW_ZR@PG^4`P*#C)""?Y200G^4($(WHE?W_ZPC0C>(0@+WH%)`"
M`%"%`0",%`$`W$4!`,1(`0!(,@$`^$4!`!PPG^400"WI``"3Y:_]_^L00+WH
M##"?Y0P@G^4,$)_E:_W_ZA20`@!0A0$`C!0!`-Q%`0`P0"WI`MI-XAS03>*L
M,)_E`AJ-XA00@>(`,)/E`#"!Y0`PH.-"_?_KE!"?Y90PG^64()_E\`#-X0$0
MH.,,`(WB4/W_ZP$:C>(!*J#C$!"!X@P`C>(8_?_K`$!0X@!0H+,)``"Z`0"$
MXB7]_^L`4%#B!0``"@$:C>($(*#A$!"!XN#\_^L`,*#C!##%YP(:C>(H,)_E
M%!"!X@`@D^4`,)'E`B`SX``PH.,#```:!0"@X0+:C>(<T(WB,("]Z.G\_^M8
MA@(`'$8!`!!&`0`!$```RO__ZO!/+>E"W4WB!-!-XN`QG^5!S8WB`%"@X0%@
MH.'4`9_E$!"-XCS`C.(`,)/E`#",Y0`PH.,J_O_K+Q"@XP!`H.$%`*#A$?W_
MZP``4.,.```*I`&?Y040H.$*___K!0"@X4$=C>*(,9_E/!"!X@`@D^4`,)'E
M`B`SX``PH.-;```:0MV-X@30C>+PC[WH!0"@X?C\_^L`@*#A!@"@X;G\_^M8
M$9_E+/W_ZP"P4.+G__\*`##;Y4BAG^5(D9_E``!3XSAQG^5\8(WB,0``"@``
M5.,$```*"Q"@X00`H.&"_/_K``!0XR$```H+`*#AX?S_ZP$@0.(",(O@`B#;
MYR\`4N,%```:`,"@XP#`P^4!('/E`0!`XB\`4N/Z__\*`3"(X@`P@^`!"E/C
MR/__J@DPH.$!*J#C`1"@XP8`H.$(4(WE!*"-Y0"PC>79_/_K$!"-X@8`H.&4
M_/_K``!0XP,``!H@,)WE#SH#X@()4^,4```*!Q"@X0``H./W_/_K``!0XP"P
MH.&Q__\*`##;Y0``4^/-__\:``!4XP(```H`,-3E+@!3XP(```I<L)_E`0"@
MX]G__^H!,-3E``!3X^O__PKX___J`1"@XP8`H.'<_/_K``!0X^7__QH<`)_E
M!A"@X:C^_^L&`*#A9OS_ZYO__^IG_/_K6(8"`"1&`0`P1@$`0$8!`$Q&`0!$
M1@$`($8!```PT.4``%/C'O\O`0$@@.(O`%/C`@"@`0$PTN0``%/C^O__&A[_
M+^$00"WI`$!0XBP```H`,-3E``!3XRD```J(_/_K`0!`X@`PA.`#`%3A)P``
M*@,@H.$"``#J!`!2X0(PH.$B```*`C"@X0$04N0O`%'C^/__"@,`5.$<```J
M`3!#X@,`5.$;```*`"#3Y2\`4N/Y__\:`3!#X@,``.H`$-/E`3!#XB\`4>,"
M```:`P!4X0,@H.'X__\Z!"!"X`(P@N(!"E/C$0``B@$ZH.,!((+B!!"@X3P`
MG^4B_/_K-`"?Y1"`O>@00+WH+`"?Y2#\_^H#`%3AYO__&@`PU.4O`%/C]___
M"A!`O>@0`)_E&/S_Z@``H.,0@+WH.)`"`"!&`0!,1@$`,$`MZ3303>)DY)_E
M9#2?Y0C`C>(`,)/E+#"-Y0`PH.,/`+[H4$2?Y5!4G^4/`*SH#P"^Z`\`K.@`
M,)[EL##,X000C>($`*#A5_W_ZP``4.,,```*!!"=Y0`@E>4!,8+@!`"3Y0``
M4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZO1#G^7L4Y_E!!"-
MX@0`H.%#_?_K``!0XPP```H$$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*
M!#"#X@0@D^4``%+C!""#Y/O__QKM___JJ$.?Y9Q3G^4$$(WB!`"@X2_]_^L`
M`%#C#```"@00G>4`()7E`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``
M4N,$((/D^___&NW__^I<0Y_E3%.?Y000C>($`*#A&_W_ZP``4.,,```*!!"=
MY0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:
M[?__ZA!#G^7\4I_E!!"-X@0`H.$'_?_K``!0XPP```H$$)WE`""5Y0$Q@N`$
M`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#Y/O__QKM___JQ$*?Y:Q2
MG^4$$(WB!`"@X?/\_^L``%#C#```"@00G>4`()7E`3&"X`0`D^4``%#C`0&"
MY_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^IX0I_E7%*?Y000C>($`*#A
MW_S_ZP``4.,,```*!!"=Y0`@E>4!,8+@!`"3Y0``4.,!`8+G\___"@0P@^($
M()/E``!2XP0@@^3[__\:[?__ZBQ"G^4,4I_E!!"-X@0`H.'+_/_K``!0XPP`
M``H$$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*!#"#X@0@D^4``%+C!""#
MY/O__QKM___JX$&?Y;Q1G^4$$(WB!`"@X;?\_^L``%#C#```"@00G>4`()7E
M`3&"X`0`D^4``%#C`0&"Y_/__PH$,(/B!""3Y0``4N,$((/D^___&NW__^J4
M09_E;%&?Y000C>($`*#AH_S_ZP``4.,,```*!!"=Y0`@E>4!,8+@!`"3Y0``
M4.,!`8+G\___"@0P@^($()/E``!2XP0@@^3[__\:[?__ZDA!G^4<49_E!!"-
MX@0`H.&/_/_K``!0XPP```H$$)WE`""5Y0$Q@N`$`)/E``!0XP$!@N?S__\*
M!#"#X@0@D^4``%+C!""#Y/O__QKM___J!!"-XO@`G^5]_/_K`!!0X@$```K<
M`)_E8OW_ZP00C>+@`)_E=OS_ZP`04.(!```*U`"?Y5O]_^L$$(WBS`"?Y6_\
M_^L`$%#B#```"IP`G^54_?_KN!"?Y8@`G^51_?_K:#"?Y0`@D^4L,)WE`B`S
MX``PH.,3```:--"-XC"`O>@$$(WBC`"?Y5W\_^L`$%#B`@``"E@`G^5"_?_K
M[/__ZG00G^4*(*#C&0"-XH'[_^L``%#CYO__&C0`G^4C$(WB./W_Z^+__^KY
M^O_K7(4!`%B&`@!01@$`$)`"`%Q&`0!D1@$`<$8!`'A&`0"(1@$`)$8!`)1&
M`0"@1@$`K$8!`#!&`0"X1@$`S$8!`.!&`0#L1@$`'$<!`/Q&`0`01P$`$$`M
MZ0C03>)L0)_E;#"?Y0``E.4`,)/E!#"-Y0`PH.,!`'#C!P``"E`PG^4`()/E
M!#"=Y0(@,^``,*#C#0``&@C0C>(0@+WH-`"?Y0T0H.$C_/_K``!0XP0```H`
M`-#E,`!0XP``4!,!`*`3``"@`P``A.7K___JQ?K_ZPB0`@!8A@(`E$8!`!!`
M+>F?^O_KF/K_ZP``4.,``)`5$("]Z'!`+>D8T$WB[#"?Y0!0H.$0$(WBY`"?
MY0`PD^44,(WE`#"@XP;\_^L`0%#B#@``"@`PU.4``%/C"P``"@40H.%^^O_K
M``!0XQ(```JH,)_E`""3Y10PG>4"(#/@`#"@XR0``!H8T(WB<("]Z(@PG^4`
M()/E%#"=Y0(@,^``,*#C!1"@`70`GP4:```:&-"-XG!`O>C3_/_J!0"@X<WZ
M_^L`8*#A!`"@X<KZ_^L``(;@`@"`XK7Z_^M$,)_E`"#@XP$0H.,8`(WI`%"-
MY30PG^4`0*#ASOK_ZQPPG^4`()/E%#"=Y0(@,^``,*#C!!"@`0@`GP7D__\*
M??K_ZUB&`@`@1P$`0$8!`$1&`0#P3RWI`ME-XOS03>+D-I_EY":?Y0!PH.$"
M"8WB`""2Y?0@@.4`(*#C]`"`X@<`D^B$0(WB#."#XB10@^('`(3HG,"-X@\`
MONB00(WB#P"LZ`,`GN@#`(SH!P"5Z`<`A.@8$(WBE`:?Y;+[_^L`0%#B`@``
M"@`PU.4``%/C``$`&C?Z_^LP^O_K`$!0XMD```H`4)3E``!5X]4```H%`*#A
MB?K_ZX``H.$!`(#B=/K_ZP`@U>4``%+C`&"@X0L```H\AI_E!D"@X00`H.$`
M((WE"#"@X0`@X.,!$*#CB?K_ZP$@]>4"0(3B``!2X_7__QH0!I_EH%"-X@(`
M`.H$`)7D``!0XPT```H8$(WBB?O_ZP!`4.+X__\*`##4Y0``4^/U__\*#/S_
MZP``4./R__\*!`"@X2CZ_^L`0%#B%```&@!0H..$D(WB^#"-X@4Q@^!T0!/E
M``!4XPP```H!@(7B"(&)X``PU.4``%/C!P``"@0`H.'X^__K`5"%X@``4.,Z
M```:!$"8Y```5./T__\:`$"@XP0`H.%+^O_K:)6?Y0"@H.$&`*#A1_K_ZP"@
MBN`!JXKB!*"*X@H`H.$P^O_K2#6?Y0`@X.,!$*#C"#"-Y0Q@C>4X-9_E`$"-
MY020C>4`@*#A1_K_ZP<=H.,(`*#A3?K_ZP$`<.,#```:/OK_ZP`0D.41`%'C
MDP``&A@0C>((`*#AX?G_ZP!04.(8```*\!2?Y0`PE^7L))_E``"1Y0$0H.,`
M@(WE3?K_ZP!@H.,"&8WBL#2?Y?00@>(`()/E`#"1Y0(@,^``,*#C)`$`&@8`
MH.$"V8WB_-"-XO"/O>@$`*#AV/G_ZP!`4.*Q__\*P___ZB@PG>4/.@/B`0E3
MX^+__QHP0)WEL?G_ZP``5.'>__\:*#"=Y8,[H.&C.Z#A!PU3X]G__QH*`*#A
M\/G_ZQ@0C>(`8*#A4`2?Y1G[_^L`$%#B?@``"@``E^7<_/_K`*!0XGH```H*
M`*#A]OG_ZP,`4.,`0*#A"P``F@0`0.(<%)_E``"*X(SY_^L``%#C!0``&@0`
M5./$```*!$"*X`4P5.4O`%/CP```"O1#G^4`,)3E`0!SXV<```H``%/C<P``
M"N`3G^7@`Y_EXOO_Z]?Y_^O8<Y_EV#.?Y0`@X.,!$*#C\(#-X0QPC>7(HY_E
M"`"-Y08`H.'B^?_K#@``ZMWY_^L`,)#E$0!3XQ```!K'^?_K`5"%X@HPH.$$
M(*#A`1"@XQ!PC>4,4(WE`,"@X08`H.$`$XWHTOG_ZP<=H.,&`*#AV/G_ZP$`
M<.,`0*#AZO__"@@`H.%G^?_K'`.?Y080H.&\^__K!@"@X<#^_^N2___J!4"@
MX9!@C>+X,(WB!#&#X&@`$^4``%#C*@``"@%0A.(%@8;@`P``Z@0`F.0``%#C
M)```"@%0A>(8$(WBP/K_ZP5`H.$`,%#B]O__"@`PT^4``%/C\___"F+Y_^L`
M4%#B$/__&N?__^JT`I_E`#"7Y=0BG^4``)#E!!"-Y0"`C>4!$*#CO?G_ZP!@
MH.-N___JFO[_ZP(9C>)H,I_E]!"!X@`@D^4`,)'E`B`SX``PH..2```:!`"@
MX0+9C>+\T(WB\$^]Z$?Y_^H-`*#C;_G_ZWA2G^53(*#C`&"@X?K^_^H`H)?E
M@O__ZDP"G^48$(WBD_K_ZP``4.-=```*`##0Y0``4^,P`%,3`3"@$P`PH`,!
M,*`3`#"$%0`PA`6+__\:"@"@X0`0H.-5^?_K`$!0XH;__PH"4*#C`##@XQ$@
MX.,`4(WE1?G_ZP8@H./T$(WB!`"@X0+Y_^OT,-WE``!3XP(``!KU,-WE0P!3
MXT(```H`,*#C`""@XP`PC>4$`*#A`#"@XS7Y_^M.!`#K`%"@X0(``.KT$(WB
M!0"@X6@$`.L"*:#C]!"-X@0`H.'L^/_K`"!0XO;__\H$`*#AD_G_ZP40H.&T
M`(WBK`0`Z_@PC>(PH$/B-+&?Y;-0C>(*0*#A,7!#X@$@]>4$`*#A"S"@X0`@
MC>4!$*#C`"#@XT3Y_^L%`%?A`D"$XO7__QHL(9_E`!"@XPP@C>7P$,WE,#&?
MY0`@X.,!$*#C!@"@X0B@C>7P@,WA-OG_ZVC__^H$0)?E``!4XSO__PH$`*#A
M(?G_ZP,`4.,W__^:!`!`XO00G^4``(3@N/C_ZP``4.,$H*`!,/__Z@``A.6H
M___J]C#=Y4$`4^.Y__\:]S#=Y4,`4^.V__\:^##=Y4@`4^.S__\:^3#=Y44`
M4^.P__\:`##@XP0`H.$Y(.#C`%"-Y>?X_^OT$(WB!`"@X2D@H..D^/_K:""?
MY?0PC>((,(WE#""-Y6PPG^4`(.#C`1"@XP8`H.$$D(WE`("-Y07Y_^LW___J
MN_C_ZX"%`0!8A@(`)$8!`#A'`0#@1@$`3$8!`$Q'`0!`1P$`()`"`)!'`0#D
M1P$`[$<!``B0`@`<1P$`E$8!`,1(`0`,2`$`'$@!`%1'`0`P1P$`_$<!`/1'
M`0!P0"WI"-!-X@Q"G^4,,I_E``"4Y0`PD^4$,(WE`#"@XRGY_^L`4*#A``"4
MY2;Y_^MH(-7E#1"@X0`PH.'@`9_E:2##Y>?Y_^L``%#C`@``"@`PT.4Q`%/C
M5P``"G;\_^L``)3E&/G_Z[@1G^4#,*#C`2"@X[3X_^L`4%#B"@``"@``E.40
M^?_K$#"5Y9@AG^4`$)/ED?C_ZQ`PE>4`,)/E"#"3Y0$%$^-/```:``"4Y07Y
M_^MT$9_E`S"@XP$@H..A^/_K`%!0X@H```I@`9_E#1"@X</Y_^L`8%#B``"4
MY3D```KX^/_K$#"5Y08@H.$`$)/E>?C_ZSAAG^4``)3E\?C_ZP!0H.$``)3E
M[OC_ZR01G^4!(*#CH/C_ZQPAG^4`$*#A!0"@X6SX_^L``)3EY?C_ZP`@H.,-
M$*#A`#"@X?P`G^5I(,/EIOG_ZP``4.,`0*#A"`"&Y0\```H'':#C!`"@X9SX
M_^L!((#B$0!0XP$`4A,`,*#A(@``BIPPG^4`()/E!#"=Y0(@,^``,*#C&P``
M&@C0C>)P@+WH!`"6Y<+]_^L``%#C`$"@X0@`AN7I__\:C`"?Y8'X_^L!,-#E
M``!3XZ7__PJC___JOOC_ZV!@G^40,)7E``"3Y00PEN4`$)/E*?K_Z\/__^H`
M`)3EM?C_ZQ`PE>4`$)/E@OC_ZZG__^HC^/_K!""6Y3@`G^4`$)+E!""@X6GX
M_^L4D`(`6(8"`'A&`0`P2`$`-$@!`#Q(`0`P1@$`*)`"`$!(`0!82`$`)$8!
M`&!(`0"$2`$`'#&?Y?!`+>D,T$WB`#"3Y00PC>4`,*#C`'"@X;+[_^L`,-#E
M`$"@X0``4^,%```*`2"`XB\`4^,"0*`!`3#2Y```4^/Z__\:V&"?Y0!05^(!
M4*`3`#"6Y0$`<^,?```*``!3XP!0H`,!4`42``!5XP<``!JH,)_E`""3Y00P
MG>4"(#/@`#"@XR0``!H,T(WB\("]Z``PU^4``%/C]/__"H00G^4$(*#C!`"@
MX6;X_^L``%#C[O__&F0PG^4`()/E!#"=Y0(@,^``,*#C$P``&@<`H.$,T(WB
M\$"]Z&#Y_^I(`)_E#1"@X2KY_^L``%#C``"&!=[__PH`,-#E``!3XS``4Q,`
M,*`#`3"@$P`PA@77__\*`3"@XP`PAN72___JR/?_ZUB&`@`(D`(`3$<!`)1&
M`0``````R#N?Y?!/+>FCWTWB0!"`XH!@@.(-(*#A`#"3Y80RC>4`,*#C`%"@
MXP3`$>4(X!'E"!"!XBPTH.'_/`/B+#R#X0Q$H.$,/(/A_T@$XC[/O^8$,(/A
M!@!1X0#`@N4$4(+E"#""Y0Q0@N40((+B[?__&@C`3>)^[XWB`#"@XPQ`H.$(
M8+SE<""4Y4B0E.5T$)3E3("4Y1APE.4<4)3E"2`BX`1`G.4($"'@!R`BX`8@
M(N`%$"'@!!`AX*)/H.&!0(3A`B"2X`0@@N$.`%SA\"C,X>G__QKX*I_E`%"0
MY0`0G>4$P)#E(."0Y0(0D>`.$)'@I>V@X1!`D.4(<)#E&&"0Y8SBCN$,D)#E
MA>*.X0'@GN`&$"3@)X&@X0<0`>`&$"'@"8^(X0'@GN`'CXCA"!"=Y261H.$,
MGXGA",`DX`(0D>`%P`S@!,`LX`80D>`%GXGA#!"1X!#`G>4)H"C@`L"<X`Z@
M"N#N'8'@"*`JX`3`G.`*P)S@X:V,X!C`G>6HL)WE`L"<X`C`G.!N@2G@`8`(
MX`F`*.`(@)S@(,"=Y6$1H.$"P)S@"<"<X&Z1(>`*D`G@ZHV(X&Z1*>`)P)S@
MZ)V,X"C`G>4"P)S@;L&,X&KA(>`(X`[@`>`NX`[`G.`PX)WE:(&@X0+@GN`!
M$)[@:N$HX`G@#N#IS8S@:N$NX`X0D>#L[8'@.!"=Y0(0D>!J$8'@::$HX`R@
M"N`(H"K@"A"1X$"@G>5LP:#A`J":X`B`FN!IH2S@#J`*X.X=@>!IH2K@"H"8
MX.&MB.!(@)WE`H"8X&F!B.!ND2S@`9`)X`R0*>`)@)C@4)"=Y6$1H.$"D)G@
M#,"9X&Z1(>`*D`G@ZHV(X&Z1*>`)P)S@Z)V,X%C`G>4"P)S@;L&,X&KA(>`(
MX`[@`>`NX`[`G.!@X)WE:(&@X0+@GN`!$)[@:N$HX`G@#N#IS8S@:N$NX`X0
MD>#L[8'@:!"=Y0(0D>!J$8'@::$HX`R@"N`(H"K@"A"1X'"@G>5LP:#A`J":
MX`B`FN!IH2S@#J`*X.X=@>!IH2K@"H"8X.&MB.!X@)WE`H"8X&F!B.!ND2S@
M`9`)X`R0*>`)D)C@@("=Y6$1H.$"@)C@#,"8X&Z!(>`*@`C@ZIV)X&Z!*.`(
MP)S@Z8V,X(C`G>4"P)S@;L&,X&KA(>`)X`[@`>`NX`[`G."0X)WE:9&@X0+@
MGN`!$)[@:N$IX`C@#N#HS8S@:N$NX`X0D>#L[8'@F!"=Y0(@D>!H$2G@#!`!
MX`D0(>!J(8+@`2"2X.X=@N"@H)WE$"B?Y6S!H.$"H)K@":":X&B1+.`.D"G@
M"9":X`*@F^!HH8K@L+"=Y6Z!+.`!@"C@X9V)X`B`FN!A$:#A`J";X`R@FN"X
ML)WE;L$AX.F-B.`)P"S@#,":X`*PF^#HK8S@;N&+X&G!(>#`L)WE",`LX`S`
MGN!H@:#A`N";X`'@GN#(L)WE:1$HX.K-C.`*$"'@`1">X`+@F^!IX8[@T+"=
MY>R=@>!J$2C@#!`AX`$0GN!LP:#A`K";X`B`F^!JX2S@V+"=Y>D=@>`)X"[@
M#N"8X`*`F^!J@8C@X+"=Y>&MCN!IX2S@`>`NX`[@F.!A$:#A`H";X`R`F.#H
ML)WE:<$AX.KMCN`*P"S@#,"8X`*`F^!I@8C@\+"=Y>Z=C.!JP2'@#L`LX`S`
MF.!NX:#A`H";X`&`F.#XL)WE:A$NX.G-C.`)$"'@`1"8X`*`F^!J@8C@[*V!
MX&D1+N`,$"'@`1"8X`"!G>5LP:#A`H"8X`BQG>4.@)C@:>$LX.H=@>`*X"[@
M#N"8X`*`F^!I@8C@$+&=Y>&=CN!JX2S@`>`NX`[@F.!A$:#A`H";X`R`F.`8
ML9WE:L$AX.GMCN`)P"S@#,"8X`*`F^!J@8C@[KV,X""AG>5IP2'@#L`LX`S`
MF.!NX:#A`J":X&F!+N`!$)K@**&=Y0N`*.#KS8S@"!"1X`*`FN!I@8C@:Y$N
MX.P=@>!LH:#A#)`IX##!G>4)D)C@`L"<X`[@G.!K@2K@X<V)X#B1G>4!@"C@
M"(">X`(@F>!AX2K@[(V(X`S@+N!K(8+@#B"2X.B=@N!`X9WEO"6?Y6S!H.$"
MX)[@"N">X&&AC.%AL0S@"*`*X`N@BN$*H)[@2.&=Y0*PGN#I[8K@:*&,X6&Q
MB^`)H`K@:1&@X6B1#.`)H(KA4)&=Y0N@FN`"D)G@#,"9X.Z=BN!HH8'A:+$!
MX`Z@"N`+H(KA#*":X%C!G>4"L)S@:+&+X.F-BN!NH8'A:<&@X0F@"N!ND0'@
M":"*X0N@FN#HG8K@8*&=Y6ZQ#.`"H)K@`1":X&ZAC.$(H`K@"Z"*X0&@FN!H
M$9WEZ:V*X`*PD>!H$8SA;K&+X`D0`>!IX:#A:)$,X`D0@>$+D)'@<!&=Y6BQ
M#N`"$)'@#!"1X.K-B>!HD8[A"I`)X`N0B>$!D)G@>!&=Y6JQ#N`"$)'@:(&!
MX&H1CN$,$`'@[)V)X`L0@>$($)'@Z;V!X(`1G>5LP:#A`A"1X`X0D>!JX8SA
M:H$,X`G@#N`(X([A`>">X(@1G>7KC8[@`A"1X&JA@>!I$8SA:^&@X0L0`>!I
ML0S@"Q"!X0J@D>"0$9WE:;$.X`(0D>`,$)'@Z,V*X&FACN$(H`K@"Z"*X0&@
MFN"8$9WE:+$.X`(0D>!ID8'@:!&.X0P0`>#LK8K@"Q"!X0D0D>#JO8'@H!&=
MY6S!H.$"$)'@#A"1X&CAC.%HD0S@"N`.X`G@CN$!D)[@J!&=Y>N=B>`"X)'@
M:A&,X6CACN`+$`'@:X&@X6JQ#.`+$('A#N"1X+`1G>5JL0C@`A"1X`P0D>#I
MS8[@:N&(X0G@#N`+X([A`1">X+CAG>5IL0C@`N">X&KACN#LK8'@:1&(X0P0
M`>`+$('A#A"1X.KM@>#`$9WE;,&@X0(0D>`($)'@:8&,X6FQ#.`*@`C@"X"(
MX00P@.4!@)C@R!&=Y6JQ#.`"$)'@:9&!X&H1C.$.$`'@"Q"!X0F0D>#0$9WE
M[HV(X`(0D>!NX:#A#!"1X&K!CN%JL0[@",`,X`O`C.$!P)S@V!&=Y>B=B>`"
M()'@:!&.X6BQ#N`)$`'@:J&"X`L0@>'0(I_E"A"1X."AG>7IS8S@`J":X&F1
MH.'HL9WE#N":X.RM@>!H$2G@#!`AX`$0GN`"X)O@:.&.X/"QG>7JC8'@;!$I
MX`H0(>`!$)[@:J&@X0*PF^`)D)O@;.$JX/BQG>4(X"[@#N"9X`*0F^#H'8'@
M;)&)X`"RG>5HP2K@`<`LX.'MCN`,P)G@81&@X0*PF^`*H)O@:)$AX`BRG>4.
MD"G@"9":X`*@F^#NS8S@$+*=Y6BABN!N@2'@#(`HX.R=B>`(@)K@;,&@X0*@
MF^`!H)K@&+*=Y6X1+.#IC8C@"1`AX`$0FN`"L)O@Z*V!X&[AB^!I$2S@(+*=
MY0@0(>`!$)[@:(&@X0+@F^`,X)[@*+*=Y6G!*.#J'8'@"L`LX`S`GN`"X)O@
M:>&.X#"RG>7AG8S@:L$HX`'`+.`,P)[@81&@X0*PF^`(@)O@:N$AX#BRG>7I
MS8S@">`NX`[@F.`"@)O@:H&(X$"RG>7LK8[@:>$AX`S@+N`.X)C@;,&@X0*`
MF^`!@)C@2+*=Y6D1+.#J[8[@"A`AX`$0F.`"@)O@:8&(X%"RG>7NG8'@:A$L
MX`X0(>`!$)C@;N&@X0*`F^`,@)C@6+*=Y6K!+N#I'8'@"<`LX`S`F.`"@)O@
M:H&(X&"RG>7AK8S@:<$NX`'`+.`,P)C@81&@X0*`F^`.@)C@:>$AX.K-C.`*
MX"[@#N"8X.SMCN!HLIWE;F&&X`*`F^`88(#E:F$AX&F!B.`,8";@!F"8X.YM
MAN!PDIWE;,&@X69!A.`"D)G@:H$LX!!`@.5X0IWE#H`HX`$0F>`($)'@`B"4
MX`4@DN!NX2S@!N`NX&HA@N`.()+@YAV!X"#@D.7A+8+@!Q"1X`[`G.`,,(#E
M%#"`Y1PP@.4`((#E"!"`Y2#`@.4D,(#E'#"?Y0`@D^6$,IWE`B`SX``PH.,!
M```:H]^-XO"/O>C/]/_K6(8"`)EY@EJAZ]ENW+P;C];!8LH00"WI@`"@X^[T
M_^L.>Y_M`""@XP![@.T->Y_M>""`Y0)[@.T,>Y_M!'N`[0Q[G^T&>X#M#'N?
M[0A[@.T,>Y_M"GN`[0Q[@.T0@+WH`2-%9P````")J\WO`````/[<NI@`````
M=E0R$`````#PX=+#````````````````\$<MZ0*0H.$H,)#E+""0Y8G!@^`#
M`%SA`#"@XP(@T^``4*#A,""0Y0%`H.$T$)#ER0^@X0$``"H!()+B`!"AXBPP
MA>6I/J#A@#&#X0(PD^"@'J'@>`"5Y3B`A>(``%#C*,"%Y3`PA>4T$(7E'P``
M&C\`6>,N``#:0)!)XBECH.$!<(;B!W.$X`@PH.%`X(3B`,"4Y00`E.4($)3E
M#""4Y1!`A.(.`%3A`,"#Y00`@^4($(/E#""#Y1`P@^+S__\:!0"@X;7\_^L'
M`%3A[?__&@9M9N`&DXG@"2"@X0<0H.$(`*#A6?3_ZWB0A>7PA[WH0'!@X@D`
M5^$)<*"A``"(X`<@H.$$$*#A4/3_ZW@PE>4#,(?@0`!3XW@PA>7PA[T8!0"@
MX0>02>`'0(3@F_S_Z\[__^H$<*#AYO__ZO!!+>DX<('B*""1Y3!@D>4RC[_F
MHC&@X3\P`^(!((/B`4"@X3@`4N-_$.#C`%"@X39OO^8"`(?@`Q#'YSP``-I`
M(&+B`!"@XYWT_^L$`*#A@_S_ZP<`H.$X(*#C`!"@XY?T_^L$`*#A<&"$Y72`
MA.5[_/_K`S#4Y00`H.$`,,7ELC#4X0$PQ>4`,)3E(S2@X0(PQ>4`,)3E`S#%
MY0LPU.4$,,7ENC#4X04PQ>4(,)3E(S2@X08PQ>4(,)3E!S#%Y1,PU.4(,,7E
MLC'4X0DPQ>40,)3E(S2@X0HPQ>40,)3E"S#%Y1LPU.4,,,7ENC'4X0TPQ>48
M,)3E(S2@X0XPQ>48,)3E#S#%Y2,PU.40,,7ELC+4X1$PQ>4@,)3E(S2@X1(P
MQ>4@,)3E$S#%Y?!!O>CT\__J."!BX@`0H.-@]/_KQ___ZO!'+>D`<*#A2&"?
MY4A0G^4&8(_@!5"/X`5@1N`!@*#A`I"@X<SS_^M&8;#A\(>]"`!`H.,$,)7D
M"2"@X0@0H.$'`*#A`4"$XC/_+^$$`%;A]___&O"'O>B(00$`@$$!`![_+^$(
M,)_E`S"/X``PD^7Q\__JY$H!``A`+>D(@+WH`0`"`#L````^````"P```#X`
M```0````/@```"4````^````,P```#X````#````/@````8````^````%```
M`#X````.````/@````T````^````)````#X````2````/@```"<````^````
M`@```#X````8````/@````D````^````"@```#X``````````````"5S+R5S
M````+W!R;V,O<V5L9B]E>&4``$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E
M<@!);G1E<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@``
M`%!!4E]414U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````
M4$523#5,24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])
M3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<`
M``!005)?0T%#2$4```!005)?1TQ/0D%,7T1%0E5'`````%!!4E]'3$]"04Q?
M5$U01$E2````4$%27U1-4$1)4@``4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X`````4$%27T-,14%./0``,0```$Q$7TQ)0E)!4EE?4$%42`!3
M65-414T``"4P,G@`````)7,E<R5S)7,`````<&%R+0`````E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*```E<SH@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@:7,@=6YS869E("AP
M;&5A<V4@<F5M;W9E(&ET(&%N9"!R971R>2!Y;W5R(&]P97)A=&EO;BD*``!0
M051(`````'!A<FP`````+G!A<@`````E<R5S8V%C:&4M)7,E<P``)7,E<W1E
M;7`M)74E<P```"5S)7-T96UP+25U+25U)7,`````&````'!E<FP`````,```
M`%!!4CHZ4&%C:V5R.CI615)324].`````#$N,#4T````56YA8FQE('1O(&-R
M96%T92!C86-H92!D:7)E8W1O<GD`````)7,Z(&-R96%T:6]N(&]F('!R:79A
M=&4@8V%C:&4@<W5B9&ER96-T;W)Y("5S(&9A:6QE9"`H97)R;F\])6DI"@``
M```M90``+2T``%5315(`````55-%4DY!344`````5$5-4$1)4@!435``+W1M
M<`````!E=F%L("=E>&5C("]U<W(O8FEN+W!E<FP@("U3("0P("1[,2LB)$`B
M?2<*:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E<B!S;VUE('-H96QL"G!A8VMA
M9V4@7U]P87)?<&P["FUY("@D4$%27TU!1TE#+"`D<&%R7W1E;7`L("1P<F]G
M;F%M92P@0'1M<&9I;&4L("5-;V1U;&5#86-H92D["D5.1"![(&EF("@D14Y6
M>U!!4E]#3$5!3GTI('L*<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I
M;&4Z.D)A<V5N86UE.PIR97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@
M/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q
M6U)E;6]V:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B72D["D9I;&4Z.D9I;F0Z
M.F9I;F1D97!T:"AS=6(@>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D
M<&%R7W1E;7`I.PIR;61I<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@
M)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E
M;7`H"E1%35!,051%(#T^("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E
M;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,
M24Y+(#T^(#`L"BD["FUY("1F:6QE;F%M92`]("1T;7`M/F9I;&5N86UE.PIP
M<FEN="`D=&UP(#P\(BXN+B(["G@],3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[
M(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA("UD("<D<&%R7W1E;7`G
M(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E>'!R(%PD>"`K(#%@"F1O
M;F4*<FT@)R1F:6QE;F%M92<*+BXN"F-L;W-E("1T;7`["F-H;6]D(#`W,#`L
M("1F:6QE;F%M93L*;7D@)&-M9"`]("(D9FEL96YA;64@/B]D978O;G5L;"`R
M/B8Q("8B.PIS>7-T96TH)&-M9"D["F]U=',H<7%;4W!A=VYE9"!B86-K9W)O
M=6YD('!R;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`D9FEL96YA;65=*3L*
M?0I]('T*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M7&XB.PI);G1E
M<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2
M.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PIM>2`D<75I970@/2`A
M)$5.5GM005)?1$5"54=].PIM>2`E<WES(#T@*`IP871H7W-E<"`@("`]/B`H
M)%Y/(#U^("]>35-7:6XO(#\@)SLG(#H@)SHG*2P*7V5X92`@("`@("`@/3X@
M*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_("<N97AE)R`Z("<G
M*2P*7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG
M(#H@)R\G*2P**3L*7W-E=%]P<F]G;F%M92@I.PIO=71S*'%Q6UPD<')O9VYA
M;64@/2`B)'!R;V=N86UE(ETI.PI?<V5T7W!A<E]T96UP*"D["F]U=',H<7%;
M7"1%3E9[4$%27U1%35!](#T@(B1%3E9[4$%27U1%35!](ETI.PIM>2`H)'-T
M87)T7W!O<RP@)&1A=&%?<&]S*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!
M4DY?7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P
M<F]G;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O
M9VYA;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S
M($5R<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&-H=6YK7W-I>F4@/2`V-"`J
M(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@+7,@7T9(.PIM>2`D;6%G:6-?
M<&]S(#T@)'-I>F4@+2`D<VEZ92`E("1C:'5N:U]S:7IE.R`C($Y/5$4Z("1M
M86=I8U]P;W,@:7,@82!M=6QT:7!L92!O9B`D8VAU;FM?<VEZ90IW:&EL92`H
M)&UA9VEC7W!O<R`^/2`P*2!["G-E96L@7T9(+"`D;6%G:6-?<&]S+"`P.PIR
M96%D(%]&2"P@)&)U9BP@)&-H=6YK7W-I>F4@*R!L96YG=&@H)%!!4E]-04=)
M0RD["FEF("@H;7D@)&D@/2!R:6YD97@H)&)U9BP@)%!!4E]-04=)0RDI(#X]
M(#`I('L*)&UA9VEC7W!O<R`K/2`D:3L*;&%S=#L*?0HD;6%G:6-?<&]S("T]
M("1C:'5N:U]S:7IE.PI]"FEF("@D;6%G:6-?<&]S(#P@,"D@>PIO=71S*'%Q
M6T-A;B=T(&9I;F0@;6%G:6,@<W1R:6YG("(D4$%27TU!1TE#(B!I;B!F:6QE
M("(D<')O9VYA;64B72D["FQA<W0@34%'24,["GT*<V5E:R!?1D@L("1M86=I
M8U]P;W,@+2`T+"`P.PIR96%D(%]&2"P@)&)U9BP@-#L*<V5E:R!?1D@L("1M
M86=I8U]P;W,@+2`T("T@=6YP86-K*").(BP@)&)U9BDL(#`["B1D871A7W!O
M<R`]('1E;&P@7T9(.PIM>2`E<F5Q=6ER95]L:7-T.PIR96%D(%]&2"P@)&)U
M9BP@-#L@("`@("`@("`@("`@("`@("`@("`@("`@("`C(')E860@=&AE(&9I
M<G-T(")&24Q%(@IW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L
M("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*
M;7D@)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<5M5;G!A8VMI;F<@1DE,12`B
M)&9U;&QN86UE(BXN+ETI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>
M*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE
M+"`D97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E
M860@7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@
M)&)U9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M
M?'!L?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&-R
M8R1E>'0B+"`D8G5F+"`P-S4U*3L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9G5L;&YA;65](#T@)&9I;&5N86UE.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE
M>R1F:6QE;F%M97T@/2`D9G5L;&YA;64["GT*96QS:68@*"`D9G5L;&YA;64@
M/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@
M>PIM>2`D9FEL96YA;64@/2!?<V%V95]A<R@B)&)A<V5N86UE)&5X="(L("1B
M=68L(#`W-34I.PIO=71S*")32$Q)0CH@)&9I;&5N86UE7&XB*3L*?0IE;'-E
M('L*)$UO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC
M<F,@/3X@)&-R8RP*;F%M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI
M<W1[)&9U;&QN86UE?2LK.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L
M($!)3D,@/2`H<W5B('L*;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U
M<FX@:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO
M9'5L94-A8VAE>R1M;V1U;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE
M=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O
M;&]A9&5R+R1I;F9O+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N
M9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL
M92T^;F5W7W1M<&9I;&4@;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE
M.B`D(2(["B1F:"T^8FEN;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F
M?2D["B1F:"T^<V5E:R@P+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@
M)&9I;&5N86UE(#T@7W-A=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O
M+3Y[8G5F?2D["B1I;F9O+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@
M)&9H+"`G/#IR87<G+"`D9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@
M(B1F:6QE;F%M92(Z("0A73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A
M<'!I;F<@9F%I;&5D.B!C86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL
M($!)3D,I.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD[
M"G)E<75I<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y
M.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z
M.D9I;&4["G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U
M:7)E7VQI<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F
M:6QE;F%M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M
M8S\D+VDI('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE
M;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O
M.PI]"GT*9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IU;FQE
M<W,@*"1B=68@97$@(E!+7#`P,UPP,#0B*2!["F]U=',H<7%;3F\@>FEP(&9O
M=6YD(&%F=&5R($9)3$4@<V5C=&EO;B!I;B!F:6QE("(D<')O9VYA;64B72D[
M"FQA<W0@34%'24,@.PI]"B1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L@
M("`@("`@("`@("`@("`@(R!S=&%R="!O9B!Z:7`*?0IM>2!`<&%R7V%R9W,[
M"FUY("@D;W5T+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*9&5L
M971E("1%3E9[4$%27T%04%]2155317T[(",@<V%N:71I>F4@*%)%55-%(&UA
M>2!B92!A('-E8W5R:71Y('!R;V)L96TI"B1Q=6EE="`](#`@=6YL97-S("1%
M3E9[4$%27T1%0E5'?3L*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E
M<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]
M('%W*`IP("`@8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN
M<W1A;&Q?<&%R"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H
M0$%21U8@86YD("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'
M5CL*)$5.5GM005)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@
M>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI
M;&4@*$!!4D=6*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=
M*2@N*BDO(&]R(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O
M7VEN8RP@)#(["GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B
M.PI]"F5L<VEF("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R
M.PI]"F5L<VEF("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D
M,2!E<2`G8B<I('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@
M)T(G*2!["B1B=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2![
M"B1Q=6EE="`](#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F
M:"P@(CX^(BP@)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R
M(CH@)"%=.PI]"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D
M,CL*?0IS:&EF="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q
M?2D@>PID96QE=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q
M=6ER92!005(Z.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S
M($!!4D=6.PHF>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE
M>&ET.PI]"GT*=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D
M;W5T*2!["GL*<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["G)E<75I<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!
M4D=6*3L*;7D@)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]
M($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L
M92@D9F@L("1P87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I
M92!Q<5M%<G)O<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@
M)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M971A(#T@)'II<"T^8V]N
M=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,[
M"B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]?B`O7B`@*%M>.ETK*3H@
M*"XK*20O;6<["GT*?3L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1P
M:"P@)SPZ<F%W)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@<F5A9"!P87(@9FEL
M92`B)'!A<B(Z("0A73L*;7D@)&)U9CL*<F5A9"`D<&@L("1B=68L(#0["F1I
M92!Q<5LB)'!A<B(@:7,@;F]T(&$@<&%R(&9I;&5=('5N;&5S<R`D8G5F(&5Q
M(")02UPP,#-<,#`T(CL*8VQO<V4@)'!H.PI]"D-R96%T95!A=&@H)&]U="D@
M.PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`HD;W5T+`I)3SHZ1FEL93HZ3U]#
M4D5!5"@I('P@24\Z.D9I;&4Z.D]?5U)/3DQ9*"D@?"!)3SHZ1FEL93HZ3U]4
M4E5.0R@I+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B
M)&]U="(Z("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM
M>2`D;&]A9&5R.PII9B`H9&5F:6YE9"`D9&%T85]P;W,I('L*<F5A9"!?1D@L
M("1L;V%D97(L("1D871A7W!O<SL*?2!E;'-E('L*;&]C86P@)"\@/2!U;F1E
M9CL*)&QO861E<B`](#Q?1D@^.PI]"FEF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PIR97%U:7)E(%!!
M4CHZ1FEL=&5R.CI0;V13=')I<#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA
M<'!L>2A<)&QO861E<BP@)#`I.PI]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["FEF
M("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(96%V>3HZ
M7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E7VUO9'5L
M97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P('L**"1B
M=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R
M8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X
M<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S?"\D?'P@9F]R96%C:"!`:6YC.PIM
M>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F;W(@0$1Y;F%,;V%D97(Z.F1L7W-H
M87)E9%]O8FIE8W1S+"!V86QU97,@)4E.0SL*;7D@)&QI8E]E>'0@/2`D0V]N
M9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@("`@("`@(R!86%@@;&EB7V5X="!V
M<R!D;&5X="`_"FUY("5W<FET=&5N.PIF;W)E86-H(&UY("1K97D@*'-O<G0@
M:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE+"`D;F%M92D["FEF("AD969I;F5D
M*&UY("1F8R`]("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&ME>7TI*2!["B@D
M9FEL92P@)&YA;64I(#T@*"1K97DL("1F8RD["GT*96QS92!["F9O<F5A8V@@
M;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME>2`]?B!M?%Y<421D:7)<12\H+BHI
M)'QI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("0Q*3L*;&%S=#L*?0II
M9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>+UTK+R@N*BDD?"D@>PII9B`H;7D@
M)')E9B`]("1-;V1U;&5#86-H97LD,7TI('L**"1F:6QE+"`D;F%M92D@/2`H
M)')E9BP@)#$I.PIL87-T.PI]"FEF("@M9B`B)&1I<B\D,2(I('L**"1F:6QE
M+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D,2D["FQA<W0["GT*?0I]"GT*;F5X
M="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*;F5X="!I9B`D=W)I='1E;GLD;F%M
M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE*2!A;F0@)&9I;&4@/7X@+UPN7%$D
M;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN=&8H<7%;4&%C:VEN9R!&24Q%("(E
M<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4I*3L*
M;7D@)&-O;G1E;G0["FEF("AR968H)&9I;&4I*2!["B1C;VYT96YT(#T@)&9I
M;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A;"`D+R`]('5N9&5F.PIO<&5N(&UY
M("1F:"P@)SPZ<F%W)RP@)&9I;&4@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F
M:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD9F@^.PIC;&]S92`D9F@["E!!4CHZ
M1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1C;VYT96YT+"`B/&5M8F5D9&5D
M/B\D;F%M92(I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^
M("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N
M="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*)&9H
M+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DL
M"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H:79E.CI::7`Z.F-O;7!U=&5#4D,S
M,B@D8V]N=&5N="DL("1N86UE*2P*<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N
M="DI+`HD8V]N=&5N="D["F]U=',H<7%;5W)I='1E;B!A<R`B)&YA;64B72D[
M"GT*?0HD>FEP+3YW<FET951O1FEL94AA;F1L92@D9F@I(&EF("1Z:7`["B1C
M86-H95]N86UE(#T@<W5B<W1R("1C86-H95]N86UE+"`P+"`T,#L*:68@*"$D
M8V%C:&5?;F%M92!A;F0@;7D@)&UT:6UE(#T@*'-T870H)&]U="DI6SE=*2![
M"FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIO<&5N(&UY("1F:"P@
M(CPZ<F%W(BP@)&]U=#L*)&-T>"T^861D9FEL92@D9F@I.PIC;&]S92`D9F@[
M"B1C86-H95]N86UE(#T@)&-T>"T^:&5X9&EG97-T.PI]"B1C86-H95]N86UE
M("X](")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PHD8V%C:&5?
M;F%M92`N/2`B0T%#2$4B.PHD9F@M/G!R:6YT*"1C86-H95]N86UE*3L*)&9H
M+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D97(I
M*2D["B1F:"T^<')I;G0H)%!!4E]-04=)0RD["B1F:"T^8VQO<V4["F-H;6]D
M(#`W-34L("1O=70["F5X:70["GT*>PIL87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["E]F:7A?<')O9VYA;64H*3L*<F5Q=6ER92!005(["E!!4CHZ
M2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H*3L*>PIR97%U:7)E($9I;&4Z.D9I
M;F0["G)E<75I<F4@07)C:&EV93HZ6FEP.PI]"FUY("1F:"`]($E/.CI&:6QE
M+3YN97<[("`@("`@("`@("`@("`@("`@("`@("`@("`@("`C($%R8VAI=F4Z
M.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ2&%N9&QE"B1F:"T^9F1O<&5N*&9I
M;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q<5MF9&]P96XH*2!F86EL960Z("0A
M73L*07)C:&EV93HZ6FEP.CIS971#:'5N:U-I>F4H+7,@7T9(*3L*;7D@)'II
M<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA
M;F1L92@D9F@L("1P<F]G;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M("D*;W(@9&EE('%Q6T5R<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P<F]G
M;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E=$-H=6YK4VEZ92@V-"`J(#$P,C0I
M.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD
M<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*
M:68@*&1E9FEN960@)$5.5GM005)?5$5-4'TI('L@(R!S:&]U;&0@8F4@<V5T
M(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@;7D@)&UE;6)E<B`H("1Z:7`M/FUE
M;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E<BT^:7-$:7)E8W1O<GD["FUY("1M
M96UB97)?;F%M92`]("1M96UB97(M/F9I;&5.86UE.PIN97AT('5N;&5S<R`D
M;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H;&EB+PHH/SHD0V]N9FEG.CI#;VYF
M:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I
M/PHH6UXO72LI"B0*?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E
M<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL
M("1E>'1R86-T7VYA;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]
M("1M96UB97(M/G5N8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P
M:6YG("(D;65M8F5R7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T
M("(D9&5S=%]N86UE(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@
M(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B72D["B1M96UB97(M/F5X
M=')A8W14;T9I;&5.86UE9"@D9&5S=%]N86UE*3L*8VAM;V0H,#4U-2P@)&1E
M<W1?;F%M92D@:68@)%Y/(&5Q(")H<'5X(CL*?0I]"GT*?0IU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*9&EE(#P\("(N(B!U;FQE<W,@
M0$%21U8["E5S86=E.B`D,"!;("U!;&EB+G!A<B!=(%L@+4ED:7(@72!;("U-
M;6]D=6QE(%T@6R!S<F,N<&%R(%T@6R!P<F]G<F%M+G!L(%T*)#`@6R`M0GPM
M8B!=(%LM3V]U=&9I;&5=('-R8RYP87(*+@HD14Y6>U!!4E]04D]'3D%-17T@
M/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6*3L*?0IS=6(@0W)E871E
M4&%T:"!["FUY("@D;F%M92D@/2!`7SL*<F5Q=6ER92!&:6QE.CI"87-E;F%M
M93L*;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA
M;64Z.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PIR97%U:7)E($9I;&4Z
M.E!A=&@["D9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@=6YL97-S*"UE("1P
M871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*<W5B(')E<75I<F5?
M;6]D=6QE<R!["G)E<75I<F4@;&EB.PIR97%U:7)E($1Y;F%,;V%D97(["G)E
M<75I<F4@:6YT96=E<CL*<F5Q=6ER92!S=')I8W0["G)E<75I<F4@=V%R;FEN
M9W,["G)E<75I<F4@=F%R<SL*<F5Q=6ER92!#87)P.PIR97%U:7)E($-A<G`Z
M.DAE879Y.PIR97%U:7)E($5R<FYO.PIR97%U:7)E($5X<&]R=&5R.CI(96%V
M>3L*<F5Q=6ER92!%>'!O<G1E<CL*<F5Q=6ER92!&8VYT;#L*<F5Q=6ER92!&
M:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.E-P96,["G)E<75I<F4@6%-,;V%D
M97(["G)E<75I<F4@0V]N9FEG.PIR97%U:7)E($E/.CI(86YD;&4["G)E<75I
M<F4@24\Z.D9I;&4["G)E<75I<F4@0V]M<')E<W,Z.EIL:6(["G)E<75I<F4@
M07)C:&EV93HZ6FEP.PIR97%U:7)E($1I9V5S=#HZ4TA!.PIR97%U:7)E(%!!
M4CL*<F5Q=6ER92!005(Z.DAE879Y.PIR97%U:7)E(%!!4CHZ1&ES=#L*<F5Q
M=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["G)E<75I<F4@4$%2.CI&:6QT
M97(Z.E!A=&-H0V]N=&5N=#L*<F5Q=6ER92!A='1R:6)U=&5S.PIE=F%L('L@
M<F5Q=6ER92!#=V0@?3L*979A;"![(')E<75I<F4@5VEN,S(@?3L*979A;"![
M(')E<75I<F4@4V-A;&%R.CI5=&EL('T["F5V86P@>R!R97%U:7)E($%R8VAI
M=F4Z.E5N>FEP.CI"=7)S="!].PIE=F%L('L@<F5Q=6ER92!4:64Z.DAA<V@Z
M.DYA;65D0V%P='5R92!].PIE=F%L('L@<F5Q=6ER92!097)L24\[(')E<75I
M<F4@4&5R;$E/.CIS8V%L87(@?3L*979A;"![(')E<75I<F4@=71F."!].PI]
M"G-U8B!?<V5T7W!A<E]T96UP('L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'T@86YD("1%3E9[4$%27U1%35!](#U^("\H+BLI+RD@>PHD<&%R7W1E;7`@
M/2`D,3L*<F5T=7)N.PI]"F9O<F5A8V@@;7D@)'!A=&@@*`HH;6%P("1%3E9[
M)%]]+"!Q=R@@4$%27U1-4$1)4B!435!$25(@5$5-4$1)4B!414U0(%1-4"`I
M*2P*<7<H($,Z7%Q414U0("]T;7`@+B`I"BD@>PIN97AT('5N;&5S<R!D969I
M;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@+7<@)'!A=&@["FUY("1U<V5R
M;F%M93L*;7D@)'!W=6ED.PIE=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^
M*2!I9B!D969I;F5D("0^.WT["FEF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN
M3F%M92D@*2!["B1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.86UE.PI]"F5L
M<VEF("AD969I;F5D("1P=W5I9"D@>PHD=7-E<FYA;64@/2`D<'=U:60["GT*
M96QS92!["B1U<V5R;F%M92`]("1%3E9[55-%4DY!345]('Q\("1%3E9[55-%
M4GT@?'P@)U-94U1%32<["GT*)'5S97)N86UE(#U^(',O7%<O7R]G.PIM>2`D
M<W1M<&1I<B`]("(D<&%T:"1S>7-[7V1E;&EM?7!A<BTB+G5N<&%C:R@B2"HB
M+"`D=7-E<FYA;64I.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*:68@*"$D14Y6
M>U!!4E]#3$5!3GT@86YD(&UY("1M=&EM92`]("AS=&%T*"1P<F]G;F%M92DI
M6SE=*2!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@9&EE
M('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*<V5E:R`D9F@L("TQ
M."P@,CL*;7D@)&)U9CL*<F5A9"`D9F@L("1B=68L(#8["FEF("@D8G5F(&5Q
M(")<,$-!0TA%(BD@>PIS965K("1F:"P@+34X+"`R.PIR96%D("1F:"P@)&)U
M9BP@-#$["B1B=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1S>7-[7V1E
M;&EM?6-A8VAE+21B=68B.PI]"F5L<V4@>PIM>2`D9&EG97-T(#T@979A;`I[
M"G)E<75I<F4@1&EG97-T.CI32$$["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^
M;F5W*#$I.PIO<&5N(&UY("1F:"P@(CPZ<F%W(BP@)'!R;V=N86UE(&]R(&1I
M92!Q<5M#86XG="!R96%D("(D<')O9VYA;64B.B`D(5T["B1C='@M/F%D9&9I
M;&4H)&9H*3L*8VQO<V4H)&9H*3L*)&-T>"T^:&5X9&EG97-T.PI]('Q\("1M
M=&EM93L*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?6-A8VAE+21D:6=E<W0B
M.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%27T-,14%.?2`](#$[
M"B1S=&UP9&ER("X]("(D<WES>U]D96QI;7UT96UP+20D(CL*?0HD14Y6>U!!
M4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*;&%S
M=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.
M5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D
M;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@
M(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY
M("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIO<&5N(&UY("1F:"P@)SXZ
M<F%W)RP@)'1E;7!N86UE(&]R(&1I92!Q<5M#86XG="!W<FET92`B)'1E;7!N
M86UE(CH@)"%=.PIP<FEN="`D9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H
M;6]D("1M;V1E+"`D=&5M<&YA;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE
M*"1T96UP;F%M92P@)&9U;&QN86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*
M?0IR971U<FX@)&9U;&QN86UE.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M
M92!\?#T@)#`["FEF("@D14Y6>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N
M86UE+"`D14Y6>U!!4E]414U0?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S
M='(H)'!R;V=N86UE+"!R:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI
M("L@,2D["GT*:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R
M;V=N86UE+"`D<WES>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H
M+"`G/"<L("1P<F]G;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M
M<R`B)'!R;V=N86UE)'-Y<WM?97AE?2(I('L*)'!R;V=N86UE("X]("1S>7-[
M7V5X97T["G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1
M)'-Y<WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES
M=',@)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T[
M"B1D:7(@/7X@<R]<421S>7-[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(I+"!L87-T
M*0II9B`M<R`B)&1I<B1S>7-[7V1E;&EM?21P<F]G;F%M921S>7-[7V5X97TB
M.PHH*"1P<F]G;F%M92`]("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(BDL
M(&QA<W0I"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE(CL*?0I]
M"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA;64@?'P]("1%3E9[
M4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M92P@)'-Y<WM?9&5L
M:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD<WES>U]D96QI;7TD<')O9VYA
M;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D
M.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS
M,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP*"1P=V0I.PHD<')O9VYA;64@
M/7X@<R]>*#\]7"Y<+C]<421S>7-[7V1E;&EM?5Q%*2\D<'=D)'-Y<WM?9&5L
M:6U]+SL*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?
M<&%R7VEN:71?96YV('L*:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]
M/2`Q("D@>PIR971U<FX["GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$
M?2`](#(["GT*9F]R("AQ=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!
M0TA%(%!23T=.04U%("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*
M9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=0
M05)?)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D
M14Y6>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%
M3E9?4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?
M5$5-4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X
M:7-T<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U
M8G-T<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[
M4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K
M*2\["GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G
M9F@I('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?
M7&XB.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@
M0$E.0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@
M<7<H"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB
M97AP"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M
M86EN.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P
M87(["E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<5MP87(N<&PZ($-A
M;B=T(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL
M92!O<B!D:7)E8W1O<GE<;ET*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R
M;V=N86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH
M*%QD*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I
M9B`D0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+
M7T58251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)2
M3U(["C$["E]?14Y$7U\*````<&5R;'AS:2YC````7U]%3E9?4$%27T-,14%.
M7U\@("`@("`@("`@("`@("``````\$@!`"!&`0``````X$8!`.1&`0#D2`$`
M*$8!`.Q(`0``````T$@!`-A(`0``````.P```#X````+````/@```!`````^
M````)0```#X````S````/@````,````^````!@```#X````4````/@````X`
M```^````#0```#X````D````/@```!(````^````)P```#X````"````/@``
M`!@````^````"0```#X````*````/@```````````````)/_?P$`````````
M+!H!``0:`0````````````$````,`P```0```!P#```!````+`,```$````V
M`P``#`````P4`0`-````*$4!`!D```!,A@(`&P````0````:````4(8"`!P`
M```$````]?[_;[0!`0`%````V`L!``8```!8!0$`"@```,D$```+````$```
M`!4``````````P```&R'`@`"````^`$``!0````1````%P```!02`0`1````
MY!$!`!(````P````$P````@````>````"````/O__V\!````_O__;W01`0#_
M__]O`P```/#__V^B$`$`````````````````````````````````````````
M````````````````````````7(8"````````````&!0!`!@4`0`8%`$`&!0!
M`!@4`0`8%`$`&!0!`!@4`0`8%`$`&!0!`!@4`0`8%`$`&!0!`!@4`0`8%`$`
M&!0!`!@4`0`8%`$`&!0!`!@4`0`8%`$`&!0!`!@4`0`8%`$`&!0!`!@4`0`8
M%`$`&!0!`!@4`0`8%`$`&!0!`!@4`0`8%`$`&!0!`!@4`0`8%`$`&!0!`!@4
M`0`8%`$`&!0!`!@4`0`8%`$`&!0!`!@4`0`8%`$`&!0!`!@4`0`8%`$`&!0!
M`!@4`0`8%`$`&!0!`!@4`0`8%`$`&!0!`!@4`0`8%`$`&!0!`!@4`0`8%`$`
M&!0!`!@4`0`8%`$`````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````#_____^$@!`$=#0SH@*%)A<W!B:6%N(#$Q+C(N
M,"TQ-"MR<&DQ*2`Q,2XR+C``02X```!A96%B:0`!)`````4V``8&"`$)`0H"
M$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E<G``+FYO=&4N
M9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H`"YD>6YS>6T`
M+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD>6X`
M+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X:61X
M`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N9&%T82YR96PN
M<F\`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"YC;VUM96YT`"Y!4DTN871T
M<FEB=71E<P``````````````````````````````````````````````````
M``````L````!`````@```%0!`0!4`0``&0```````````````0`````````3
M````!P````(```!P`0$`<`$``"0```````````````0`````````)@````<`
M```"````E`$!`)0!```@```````````````$`````````#0```#V__]O`@``
M`+0!`0"T`0``I`,```4`````````!`````0````^````"P````(```!8!0$`
M6`4``(`&```&`````0````0````0````1@````,````"````V`L!`-@+``#)
M!``````````````!`````````$X```#___]O`@```*(0`0"B$```T`````4`
M`````````@````(```!;````_O__;P(```!T$0$`=!$``'`````&`````P``
M``0`````````:@````D````"````Y!$!`.01```P````!0`````````$````
M"````',````)````0@```!02`0`4$@``^`$```4````6````!`````@```!\
M`````0````8````,%`$`#!0```P```````````````0`````````=P````$`
M```&````&!0!`!@4```(`P`````````````$````!````((````!````!@``
M`"`7`0`@%P``""X`````````````"`````````"(`````0````8````H10$`
M*$4```@```````````````0`````````C@````$````"````,$4!`#!%```0
M00`````````````$`````````)8````!``!P@@```$"&`0!`A@``"`````T`
M````````!`````````"A`````0````(```!(A@$`2(8```0`````````````
M``0`````````JP````X````#````3(8"`$R&```$```````````````$````
M!````+<````/`````P```%"&`@!0A@``!```````````````!`````0```##
M`````0````,```!8A@(`6(8```0```````````````@`````````T`````8`
M```#````7(8"`%R&```0`0``!@`````````$````"````-D````!`````P``
M`&R'`@!LAP``#`$`````````````!`````0```#>`````0````,`````D`(`
M`)```!````````````````0`````````Y`````@````#````$)`"`!"0```H
M$``````````````(`````````.D````!````,``````````0D```)@``````
M`````````0````$```#R`````P``<```````````-I```"\`````````````
M``$``````````0````,``````````````&60```"`0`````````````!````
$````````
